@@ -1,4 +1,5 @@
 """Provide a CLI for aiomysensors."""
+
 import logging
 
 import click
@@ -9,7 +10,7 @@ from .gateway_mqtt import mqtt_gateway
 from .gateway_serial import serial_gateway
 from .gateway_tcp import tcp_gateway
 
-SETTINGS = dict(help_option_names=["-h", "--help"])
+SETTINGS = {"help_option_names": ["-h", "--help"]}
 
 
 @click.group(
